@@ -236,10 +236,11 @@ def Correct_Meter_with_Inv_data_v01(df, pos_Meter, pos_Meter_Cum, clipping_KW, d
             aux_e_filled_date = []
             
             e_to_distribute = aux_f['E_sum_Fill'][pos[p]:pos[p+1]]
-            e_to_distribute = e_to_distribute.sort_values( ascending = False)
+            # Manual sorting to match old sorting algorithm in Python 2.7 process
+            sort = e_to_distribute.argsort()[::-1]
+            e_to_distribute = e_to_distribute[sort]
             e_to_fill = aux_f['Missing_KW'][pos[p+1]] 
-            #print p, e_to_fill
-            #
+
             k = 0
             while k < len(e_to_distribute):
                 if e_to_distribute[k] < e_to_fill:
@@ -249,7 +250,6 @@ def Correct_Meter_with_Inv_data_v01(df, pos_Meter, pos_Meter_Cum, clipping_KW, d
                 #else:
                     #k = len(e_to_distribute)               
                 k = k+1
-            # 
                 
             ##input scale factor due to left over energy            
             if aux_e_filled_value != []:
@@ -311,7 +311,7 @@ def Correct_Meter_with_Inv_data_v01(df, pos_Meter, pos_Meter_Cum, clipping_KW, d
         # function to scale up backfilled meter data to match the total target energy
         # intelligently scales to prevent meter from going above POI limit
         def capped_scale(data, goal_energy, multiplier, limit):
-            data = (data * multiplier).clip_upper(limit)
+            data = (data * multiplier).clip(upper=limit)
             missing_energy = goal_energy - data.sum()
             #print goal_energy / data.sum(), goal_energy, data.sum(), missing_energy
 
@@ -327,7 +327,6 @@ def Correct_Meter_with_Inv_data_v01(df, pos_Meter, pos_Meter_Cum, clipping_KW, d
                     def smooth_out(series):
                         return series.sum() / series.size
                     
-                    print("smearing data")
                     data = data.rolling(3, center=True, min_periods=1).apply(smooth_out)
                     
                 # filter out clipping points
