@@ -94,7 +94,7 @@ class DashboardSession(object):
                      'Thunderegg', 'Vale', 'Wagyu', 'Warren', 'Wendell', 'West Moore II', 'Yellow Jacket']
     battery_ac_funds = ['LGE']
     battery_ac_sites = df_keys.query("Fund in @battery_ac_funds").index
-    battery_dc_sites = ['Salt Point', 'Dubois']
+    battery_dc_sites = ['Salt Point', 'Dubois', 'Landau II', 'Clendenin A']
     
     # Type annotations & docstrings for documentation
     df_keys: dict
@@ -168,7 +168,6 @@ class DashboardSession(object):
         return 'DashboardSession object with {} projects'.format(len(self.project_list))
 
 
-    @func_timer
     def add_project(self, project_name, get_neighbors=True):
         """Adds & initializes a [Project][ccrenew.dashboard.project.Project]
         to a [DashboardSession][ccrenew.dashboard.session.DashboardSession] instance.
@@ -188,7 +187,7 @@ class DashboardSession(object):
             return
         else:
             try:
-                project = self.__initialize_project(project_name, get_neighbors)
+                project = self.__initialize_project(project_name, get_neighbors=get_neighbors)
                 self.project_list[project.project_name] = project
             except RuntimeError as e:
                 print(e)
@@ -203,11 +202,11 @@ class DashboardSession(object):
             get_neighbors (bool, optional): See [add_project()][ccrenew.dashboard.session.DashboardSession.add_project].
         """
         if isinstance(project_list, (str, unicode)):
-            self.add_project(project_list, get_neighbors)
+            self.add_project(project_list, get_neighbors=get_neighbors)
 
         elif isinstance(project_list, list):
             for project_name in project_list:
-                self.add_project(project_name, get_neighbors)
+                self.add_project(project_name, get_neighbors=get_neighbors)
         
         else:
             raise TypeError("`project_list` must be a string or Python list! Please reformat input and try again.")
@@ -239,7 +238,7 @@ class DashboardSession(object):
 
         if get_neighbors:
             # Find all neighbors that satisfy the distance and equipment requirements
-            neighbor_list = neighbs.find_nearby_similar_projects(project_name, print_data=False).index.tolist()
+            neighbor_list = neighbs.find_nearby_similar_projects(project_name, print_data=False, include_retired=True).index.tolist()
             
             # Then remove the search project from the list
             # (Sometimes it will return an empty list if there is some data missing in `df_keys`) so we need to check if it returned a non-empty list first
@@ -294,13 +293,12 @@ class DashboardSession(object):
         try:
             project = self.project_list[project_name]
         except KeyError:
-            self.add_project(project_name, get_neighbors)
+            self.add_project(project_name, get_neighbors=get_neighbors)
             project = self.project_list[project_name]
         
         return project
 
 
-    @func_timer
     def process_project(self, project_name, reprocess=False):
         """Processes data for the given [Project][ccrenew.dashboard.project.Project].
 
@@ -312,7 +310,7 @@ class DashboardSession(object):
                 outside of the config/powertrack file or a change is made to a neighbor.
         """
         if isinstance(project_name, list):
-            self.process_projects(project_name, reprocess)
+            self.process_projects(project_name, reprocess=reprocess)
         elif isinstance(project_name, (str, unicode, Project)):
             start = time.time()
             print(f'Processing {project_name}....')
@@ -320,8 +318,13 @@ class DashboardSession(object):
             project = self.get_project(project_name)
 
             # Pull the last updated dates from the filesystem for the config & Powertrack files
-            last_update_config_file = os.path.getmtime(project.config_filepath)
-            last_update_powertrack_file = os.path.getmtime(project.powertrack_filepath)
+            try:
+                last_update_config_file = os.path.getmtime(project.config_filepath)
+                last_update_powertrack_file = os.path.getmtime(project.powertrack_filepath)
+            except FileNotFoundError:
+                self.__update_project_filepaths()
+                last_update_config_file = os.path.getmtime(project.config_filepath)
+                last_update_powertrack_file = os.path.getmtime(project.powertrack_filepath)
 
             # Check if the config file or the Powertrack file has been updated.
             # If not we don't need to process.
@@ -372,14 +375,14 @@ class DashboardSession(object):
         """
         if isinstance(project_list, (str, unicode, Project)):
             project_name = project_list
-            project = self.process_project(project_name, reprocess)
+            project = self.process_project(project_name, reprocess=reprocess)
             return project
         elif isinstance(project_list, list):
             for i, project_name in enumerate(project_list):
                 print('*******************************************************')
                 print(f'Processing {project_name} - Project {i+1} of {len(project_list)}.')
                 print('*******************************************************')
-                self.process_project(project_name, reprocess)
+                self.process_project(project_name, reprocess=reprocess)
         else:
             raise TypeError("`project_list` must be a string or Python list! Please reformat input and try again.")
     
@@ -393,6 +396,15 @@ class DashboardSession(object):
         self.process_projects(project_list)
 
 
+    def remove_project(self, project_name:str) -> None:
+        """Remove the selected project from the active session.
+
+        Args:
+            project_name (str): The name of the [Project][ccrenew.dashboad.project.Project]
+                to remove from the [DashboardSession][ccrenew.dashboard.session.DashboardSession] instance.
+        """
+        del self.project_list[project_name]
+
     def get_ss_comments(self, project_name:str, num_comments: int=None) -> None:
         """Prints Smartsheet comments for the [Project][ccrenew.dashboard.project.Project].
 
@@ -403,7 +415,7 @@ class DashboardSession(object):
                 Smartsheet. Defaults to None, which will show all comments starting in Jan 2021.
         """
         project = self.get_project(project_name, get_neighbors=False)
-        project.get_ss_comments(num_comments)
+        project.get_ss_comments(num_comments=num_comments)
 
 
     def save_pickle(self, project_name, store_plots=False):
@@ -418,10 +430,10 @@ class DashboardSession(object):
             TypeError: if the wrong type is supplied to `project_name`.
         """
         if isinstance(project_name, list):
-            self.save_pickles(project_name, store_plots)
+            self.save_pickles(project_name, store_plots=store_plots)
         elif isinstance(project_name, (str, Project)):
             project = self.process_project(project_name)
-            project.save_pickle(store_plots)
+            project.save_pickle(store_plots=store_plots)
         else:
             raise TypeError("`project_name` must be a string or Project object! Please reformat input and try again.")
 
@@ -436,13 +448,13 @@ class DashboardSession(object):
         """
         if isinstance(project_list, (str, Project)):
             project_name = project_list
-            self.save_pickle(project_name, store_plots)
+            self.save_pickle(project_name, store_plots=store_plots)
         elif isinstance(project_list, list):
             for i, project_name in enumerate(project_list):
                 print('*******************************************************')
                 print(f'Pickling {project_name} - Project {i+1} of {len(project_list)}.')
                 print('*******************************************************')
-                self.save_pickle(project_name, store_plots)
+                self.save_pickle(project_name, store_plots=store_plots)
         else:
             raise TypeError("`project_list` must be a string or Python list! Please reformat input and try again.")
 
@@ -455,7 +467,7 @@ class DashboardSession(object):
         """
 
         warnings.warn('pickle_project will be deprecated in a future version. Please use `save_pickle` instead', FutureWarning)
-        self.save_pickle(project_name, store_plots)
+        self.save_pickle(project_name, store_plots=store_plots)
 
 
     def pickle_projects(self, project_list, store_plots=False):
@@ -464,7 +476,7 @@ class DashboardSession(object):
             FutureWarning: This method will be deprecated in a future version. Use [save_pickle][ccrenew.dashboard.session.DashboardSession.save_pickle] instead.
         warnings.warn('pickle_project will be deprecated in a future version. Please use `save_pickles` instead', FutureWarning)
         """
-        self.save_pickles(project_list, store_plots)
+        self.save_pickles(project_list, store_plots=store_plots)
 
 
     def load_pickle(self, project_name, year=None, data_cutoff_date=None, show_plots=False):
@@ -536,12 +548,12 @@ class DashboardSession(object):
         """
         if isinstance(project_list, str):
             project_name = project_list
-            self.load_pickle(project_name, year, data_cutoff_date, show_plots)
+            self.load_pickle(project_name, year=year, data_cutoff_date=data_cutoff_date, show_plots=show_plots)
             return
         elif isinstance(project_list, list):
             for project_name in project_list:
                 try:
-                    project = self.load_pickle(project_name, year, data_cutoff_date, show_plots)
+                    project = self.load_pickle(project_name, year=year, data_cutoff_date=data_cutoff_date, show_plots=show_plots)
                     project.plotter = None
                 except Exception as e:
                     print(e)
@@ -623,9 +635,9 @@ class DashboardSession(object):
                     print('Plots already drawn. Add a new plot to the `plot_list` attribute or set `redraw` = True if you\'d like to redraw the current plots')
                     return
                 else:
-                    self.__draw_plots(project, plot_order, *args, **kwargs)
+                    self.__draw_plots(project, plot_order=plot_order, *args, **kwargs)
             else:
-                self.__draw_plots(project, plot_order, *args, **kwargs)
+                self.__draw_plots(project, plot_order=plot_order, *args, **kwargs)
         elif isinstance(project_name, list):
             project_list = project_name
             project_count = len(project_list)
