@@ -31,8 +31,8 @@ def dfs_to_excel(output_filepath, df_dict):
         for sheet_name, df in df_dict.items():
             df.to_excel(writer, sheet_name)
     
-def write_to_s3(df, folder, filename):
+def write_to_s3(df, folder, filename, index=False, header=True):
     filepath = '{}/{}'.format(folder, filename)
     fs = s3fs.S3FileSystem()
     with fs.open(filepath, 'wb') as f:
-        df.to_csv(f,index=False)
\ No newline at end of file
+        df.to_csv(f,index=index, header=header)
\ No newline at end of file
